@@ -13,9 +13,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
-import exceptions
 from typing import Generic, TypeVar
-from threading import Thread
 
 T = TypeVar('T')
 
